# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/assistant/embedded/v1alpha2/embedded_assistant.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import latlng_pb2 as google_dot_type_dot_latlng__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/assistant/embedded/v1alpha2/embedded_assistant.proto',
  package='google.assistant.embedded.v1alpha2',
  syntax='proto3',
  serialized_pb=_b('\n;google/assistant/embedded/v1alpha2/embedded_assistant.proto\x12\"google.assistant.embedded.v1alpha2\x1a\x1cgoogle/api/annotations.proto\x1a\x18google/type/latlng.proto\"\xdd\x02\n\x0c\x41ssistConfig\x12L\n\x0f\x61udio_in_config\x18\x01 \x01(\x0b\x32\x31.google.assistant.embedded.v1alpha2.AudioInConfigH\x00\x12\x14\n\ntext_query\x18\x06 \x01(\tH\x00\x12L\n\x10\x61udio_out_config\x18\x02 \x01(\x0b\x32\x32.google.assistant.embedded.v1alpha2.AudioOutConfig\x12J\n\x0f\x64ialog_state_in\x18\x03 \x01(\x0b\x32\x31.google.assistant.embedded.v1alpha2.DialogStateIn\x12G\n\rdevice_config\x18\x04 \x01(\x0b\x32\x30.google.assistant.embedded.v1alpha2.DeviceConfigB\x06\n\x04type\"\xb6\x01\n\rAudioInConfig\x12L\n\x08\x65ncoding\x18\x01 \x01(\x0e\x32:.google.assistant.embedded.v1alpha2.AudioInConfig.Encoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x05\"<\n\x08\x45ncoding\x12\x18\n\x14\x45NCODING_UNSPECIFIED\x10\x00\x12\x0c\n\x08LINEAR16\x10\x01\x12\x08\n\x04\x46LAC\x10\x02\"\xe3\x01\n\x0e\x41udioOutConfig\x12M\n\x08\x65ncoding\x18\x01 \x01(\x0e\x32;.google.assistant.embedded.v1alpha2.AudioOutConfig.Encoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x05\x12\x19\n\x11volume_percentage\x18\x03 \x01(\x05\"L\n\x08\x45ncoding\x12\x18\n\x14\x45NCODING_UNSPECIFIED\x10\x00\x12\x0c\n\x08LINEAR16\x10\x01\x12\x07\n\x03MP3\x10\x02\x12\x0f\n\x0bOPUS_IN_OGG\x10\x03\"\x8f\x01\n\rDialogStateIn\x12\x1a\n\x12\x63onversation_state\x18\x01 \x01(\x0c\x12\x15\n\rlanguage_code\x18\x02 \x01(\t\x12K\n\x0f\x64\x65vice_location\x18\x05 \x01(\x0b\x32\x32.google.assistant.embedded.v1alpha2.DeviceLocation\"\x1e\n\x08\x41udioOut\x12\x12\n\naudio_data\x18\x01 \x01(\x0c\"\xa5\x02\n\x0e\x44ialogStateOut\x12!\n\x19supplemental_display_text\x18\x01 \x01(\t\x12\x1a\n\x12\x63onversation_state\x18\x02 \x01(\x0c\x12Z\n\x0fmicrophone_mode\x18\x03 \x01(\x0e\x32\x41.google.assistant.embedded.v1alpha2.DialogStateOut.MicrophoneMode\x12\x19\n\x11volume_percentage\x18\x04 \x01(\x05\"]\n\x0eMicrophoneMode\x12\x1f\n\x1bMICROPHONE_MODE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43LOSE_MICROPHONE\x10\x01\x12\x14\n\x10\x44IALOG_FOLLOW_ON\x10\x02\"o\n\rAssistRequest\x12\x42\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x30.google.assistant.embedded.v1alpha2.AssistConfigH\x00\x12\x12\n\x08\x61udio_in\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04type\"\xce\x03\n\x0e\x41ssistResponse\x12P\n\nevent_type\x18\x01 \x01(\x0e\x32<.google.assistant.embedded.v1alpha2.AssistResponse.EventType\x12?\n\taudio_out\x18\x03 \x01(\x0b\x32,.google.assistant.embedded.v1alpha2.AudioOut\x12G\n\rdevice_action\x18\x06 \x01(\x0b\x32\x30.google.assistant.embedded.v1alpha2.DeviceAction\x12S\n\x0espeech_results\x18\x02 \x03(\x0b\x32;.google.assistant.embedded.v1alpha2.SpeechRecognitionResult\x12L\n\x10\x64ialog_state_out\x18\x05 \x01(\x0b\x32\x32.google.assistant.embedded.v1alpha2.DialogStateOut\"=\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45ND_OF_UTTERANCE\x10\x01\"@\n\x17SpeechRecognitionResult\x12\x12\n\ntranscript\x18\x01 \x01(\t\x12\x11\n\tstability\x18\x02 \x01(\x02\":\n\x0c\x44\x65viceConfig\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x17\n\x0f\x64\x65vice_model_id\x18\x03 \x01(\t\"+\n\x0c\x44\x65viceAction\x12\x1b\n\x13\x64\x65vice_request_json\x18\x01 \x01(\t\"D\n\x0e\x44\x65viceLocation\x12*\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x13.google.type.LatLngH\x00\x42\x06\n\x04type2\x88\x01\n\x11\x45mbeddedAssistant\x12s\n\x06\x41ssist\x12\x31.google.assistant.embedded.v1alpha2.AssistRequest\x1a\x32.google.assistant.embedded.v1alpha2.AssistResponse(\x01\x30\x01\x42\x86\x01\n&com.google.assistant.embedded.v1alpha2B\x0e\x41ssistantProtoP\x01ZJgoogle.golang.org/genproto/googleapis/assistant/embedded/v1alpha2;embeddedb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_type_dot_latlng__pb2.DESCRIPTOR,])



_AUDIOINCONFIG_ENCODING = _descriptor.EnumDescriptor(
  name='Encoding',
  full_name='google.assistant.embedded.v1alpha2.AudioInConfig.Encoding',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENCODING_UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINEAR16', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLAC', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=630,
  serialized_end=690,
)
_sym_db.RegisterEnumDescriptor(_AUDIOINCONFIG_ENCODING)

_AUDIOOUTCONFIG_ENCODING = _descriptor.EnumDescriptor(
  name='Encoding',
  full_name='google.assistant.embedded.v1alpha2.AudioOutConfig.Encoding',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENCODING_UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINEAR16', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP3', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPUS_IN_OGG', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=844,
  serialized_end=920,
)
_sym_db.RegisterEnumDescriptor(_AUDIOOUTCONFIG_ENCODING)

_DIALOGSTATEOUT_MICROPHONEMODE = _descriptor.EnumDescriptor(
  name='MicrophoneMode',
  full_name='google.assistant.embedded.v1alpha2.DialogStateOut.MicrophoneMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MICROPHONE_MODE_UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLOSE_MICROPHONE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIALOG_FOLLOW_ON', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1301,
  serialized_end=1394,
)
_sym_db.RegisterEnumDescriptor(_DIALOGSTATEOUT_MICROPHONEMODE)

_ASSISTRESPONSE_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='google.assistant.embedded.v1alpha2.AssistResponse.EventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EVENT_TYPE_UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='END_OF_UTTERANCE', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1911,
  serialized_end=1972,
)
_sym_db.RegisterEnumDescriptor(_ASSISTRESPONSE_EVENTTYPE)


_ASSISTCONFIG = _descriptor.Descriptor(
  name='AssistConfig',
  full_name='google.assistant.embedded.v1alpha2.AssistConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_in_config', full_name='google.assistant.embedded.v1alpha2.AssistConfig.audio_in_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text_query', full_name='google.assistant.embedded.v1alpha2.AssistConfig.text_query', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audio_out_config', full_name='google.assistant.embedded.v1alpha2.AssistConfig.audio_out_config', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dialog_state_in', full_name='google.assistant.embedded.v1alpha2.AssistConfig.dialog_state_in', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_config', full_name='google.assistant.embedded.v1alpha2.AssistConfig.device_config', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='google.assistant.embedded.v1alpha2.AssistConfig.type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=156,
  serialized_end=505,
)


_AUDIOINCONFIG = _descriptor.Descriptor(
  name='AudioInConfig',
  full_name='google.assistant.embedded.v1alpha2.AudioInConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoding', full_name='google.assistant.embedded.v1alpha2.AudioInConfig.encoding', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sample_rate_hertz', full_name='google.assistant.embedded.v1alpha2.AudioInConfig.sample_rate_hertz', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AUDIOINCONFIG_ENCODING,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=690,
)


_AUDIOOUTCONFIG = _descriptor.Descriptor(
  name='AudioOutConfig',
  full_name='google.assistant.embedded.v1alpha2.AudioOutConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoding', full_name='google.assistant.embedded.v1alpha2.AudioOutConfig.encoding', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sample_rate_hertz', full_name='google.assistant.embedded.v1alpha2.AudioOutConfig.sample_rate_hertz', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volume_percentage', full_name='google.assistant.embedded.v1alpha2.AudioOutConfig.volume_percentage', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AUDIOOUTCONFIG_ENCODING,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=693,
  serialized_end=920,
)


_DIALOGSTATEIN = _descriptor.Descriptor(
  name='DialogStateIn',
  full_name='google.assistant.embedded.v1alpha2.DialogStateIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conversation_state', full_name='google.assistant.embedded.v1alpha2.DialogStateIn.conversation_state', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='google.assistant.embedded.v1alpha2.DialogStateIn.language_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_location', full_name='google.assistant.embedded.v1alpha2.DialogStateIn.device_location', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=923,
  serialized_end=1066,
)


_AUDIOOUT = _descriptor.Descriptor(
  name='AudioOut',
  full_name='google.assistant.embedded.v1alpha2.AudioOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_data', full_name='google.assistant.embedded.v1alpha2.AudioOut.audio_data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1098,
)


_DIALOGSTATEOUT = _descriptor.Descriptor(
  name='DialogStateOut',
  full_name='google.assistant.embedded.v1alpha2.DialogStateOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='supplemental_display_text', full_name='google.assistant.embedded.v1alpha2.DialogStateOut.supplemental_display_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='conversation_state', full_name='google.assistant.embedded.v1alpha2.DialogStateOut.conversation_state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='microphone_mode', full_name='google.assistant.embedded.v1alpha2.DialogStateOut.microphone_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volume_percentage', full_name='google.assistant.embedded.v1alpha2.DialogStateOut.volume_percentage', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DIALOGSTATEOUT_MICROPHONEMODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1394,
)


_ASSISTREQUEST = _descriptor.Descriptor(
  name='AssistRequest',
  full_name='google.assistant.embedded.v1alpha2.AssistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='google.assistant.embedded.v1alpha2.AssistRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audio_in', full_name='google.assistant.embedded.v1alpha2.AssistRequest.audio_in', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='google.assistant.embedded.v1alpha2.AssistRequest.type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1396,
  serialized_end=1507,
)


_ASSISTRESPONSE = _descriptor.Descriptor(
  name='AssistResponse',
  full_name='google.assistant.embedded.v1alpha2.AssistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_type', full_name='google.assistant.embedded.v1alpha2.AssistResponse.event_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audio_out', full_name='google.assistant.embedded.v1alpha2.AssistResponse.audio_out', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_action', full_name='google.assistant.embedded.v1alpha2.AssistResponse.device_action', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='speech_results', full_name='google.assistant.embedded.v1alpha2.AssistResponse.speech_results', index=3,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dialog_state_out', full_name='google.assistant.embedded.v1alpha2.AssistResponse.dialog_state_out', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ASSISTRESPONSE_EVENTTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1510,
  serialized_end=1972,
)


_SPEECHRECOGNITIONRESULT = _descriptor.Descriptor(
  name='SpeechRecognitionResult',
  full_name='google.assistant.embedded.v1alpha2.SpeechRecognitionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transcript', full_name='google.assistant.embedded.v1alpha2.SpeechRecognitionResult.transcript', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stability', full_name='google.assistant.embedded.v1alpha2.SpeechRecognitionResult.stability', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1974,
  serialized_end=2038,
)


_DEVICECONFIG = _descriptor.Descriptor(
  name='DeviceConfig',
  full_name='google.assistant.embedded.v1alpha2.DeviceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='google.assistant.embedded.v1alpha2.DeviceConfig.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_model_id', full_name='google.assistant.embedded.v1alpha2.DeviceConfig.device_model_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2040,
  serialized_end=2098,
)


_DEVICEACTION = _descriptor.Descriptor(
  name='DeviceAction',
  full_name='google.assistant.embedded.v1alpha2.DeviceAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_request_json', full_name='google.assistant.embedded.v1alpha2.DeviceAction.device_request_json', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2100,
  serialized_end=2143,
)


_DEVICELOCATION = _descriptor.Descriptor(
  name='DeviceLocation',
  full_name='google.assistant.embedded.v1alpha2.DeviceLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinates', full_name='google.assistant.embedded.v1alpha2.DeviceLocation.coordinates', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='google.assistant.embedded.v1alpha2.DeviceLocation.type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2145,
  serialized_end=2213,
)

_ASSISTCONFIG.fields_by_name['audio_in_config'].message_type = _AUDIOINCONFIG
_ASSISTCONFIG.fields_by_name['audio_out_config'].message_type = _AUDIOOUTCONFIG
_ASSISTCONFIG.fields_by_name['dialog_state_in'].message_type = _DIALOGSTATEIN
_ASSISTCONFIG.fields_by_name['device_config'].message_type = _DEVICECONFIG
_ASSISTCONFIG.oneofs_by_name['type'].fields.append(
  _ASSISTCONFIG.fields_by_name['audio_in_config'])
_ASSISTCONFIG.fields_by_name['audio_in_config'].containing_oneof = _ASSISTCONFIG.oneofs_by_name['type']
_ASSISTCONFIG.oneofs_by_name['type'].fields.append(
  _ASSISTCONFIG.fields_by_name['text_query'])
_ASSISTCONFIG.fields_by_name['text_query'].containing_oneof = _ASSISTCONFIG.oneofs_by_name['type']
_AUDIOINCONFIG.fields_by_name['encoding'].enum_type = _AUDIOINCONFIG_ENCODING
_AUDIOINCONFIG_ENCODING.containing_type = _AUDIOINCONFIG
_AUDIOOUTCONFIG.fields_by_name['encoding'].enum_type = _AUDIOOUTCONFIG_ENCODING
_AUDIOOUTCONFIG_ENCODING.containing_type = _AUDIOOUTCONFIG
_DIALOGSTATEIN.fields_by_name['device_location'].message_type = _DEVICELOCATION
_DIALOGSTATEOUT.fields_by_name['microphone_mode'].enum_type = _DIALOGSTATEOUT_MICROPHONEMODE
_DIALOGSTATEOUT_MICROPHONEMODE.containing_type = _DIALOGSTATEOUT
_ASSISTREQUEST.fields_by_name['config'].message_type = _ASSISTCONFIG
_ASSISTREQUEST.oneofs_by_name['type'].fields.append(
  _ASSISTREQUEST.fields_by_name['config'])
_ASSISTREQUEST.fields_by_name['config'].containing_oneof = _ASSISTREQUEST.oneofs_by_name['type']
_ASSISTREQUEST.oneofs_by_name['type'].fields.append(
  _ASSISTREQUEST.fields_by_name['audio_in'])
_ASSISTREQUEST.fields_by_name['audio_in'].containing_oneof = _ASSISTREQUEST.oneofs_by_name['type']
_ASSISTRESPONSE.fields_by_name['event_type'].enum_type = _ASSISTRESPONSE_EVENTTYPE
_ASSISTRESPONSE.fields_by_name['audio_out'].message_type = _AUDIOOUT
_ASSISTRESPONSE.fields_by_name['device_action'].message_type = _DEVICEACTION
_ASSISTRESPONSE.fields_by_name['speech_results'].message_type = _SPEECHRECOGNITIONRESULT
_ASSISTRESPONSE.fields_by_name['dialog_state_out'].message_type = _DIALOGSTATEOUT
_ASSISTRESPONSE_EVENTTYPE.containing_type = _ASSISTRESPONSE
_DEVICELOCATION.fields_by_name['coordinates'].message_type = google_dot_type_dot_latlng__pb2._LATLNG
_DEVICELOCATION.oneofs_by_name['type'].fields.append(
  _DEVICELOCATION.fields_by_name['coordinates'])
_DEVICELOCATION.fields_by_name['coordinates'].containing_oneof = _DEVICELOCATION.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['AssistConfig'] = _ASSISTCONFIG
DESCRIPTOR.message_types_by_name['AudioInConfig'] = _AUDIOINCONFIG
DESCRIPTOR.message_types_by_name['AudioOutConfig'] = _AUDIOOUTCONFIG
DESCRIPTOR.message_types_by_name['DialogStateIn'] = _DIALOGSTATEIN
DESCRIPTOR.message_types_by_name['AudioOut'] = _AUDIOOUT
DESCRIPTOR.message_types_by_name['DialogStateOut'] = _DIALOGSTATEOUT
DESCRIPTOR.message_types_by_name['AssistRequest'] = _ASSISTREQUEST
DESCRIPTOR.message_types_by_name['AssistResponse'] = _ASSISTRESPONSE
DESCRIPTOR.message_types_by_name['SpeechRecognitionResult'] = _SPEECHRECOGNITIONRESULT
DESCRIPTOR.message_types_by_name['DeviceConfig'] = _DEVICECONFIG
DESCRIPTOR.message_types_by_name['DeviceAction'] = _DEVICEACTION
DESCRIPTOR.message_types_by_name['DeviceLocation'] = _DEVICELOCATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AssistConfig = _reflection.GeneratedProtocolMessageType('AssistConfig', (_message.Message,), dict(
  DESCRIPTOR = _ASSISTCONFIG,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.AssistConfig)
  ))
_sym_db.RegisterMessage(AssistConfig)

AudioInConfig = _reflection.GeneratedProtocolMessageType('AudioInConfig', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOINCONFIG,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.AudioInConfig)
  ))
_sym_db.RegisterMessage(AudioInConfig)

AudioOutConfig = _reflection.GeneratedProtocolMessageType('AudioOutConfig', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOOUTCONFIG,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.AudioOutConfig)
  ))
_sym_db.RegisterMessage(AudioOutConfig)

DialogStateIn = _reflection.GeneratedProtocolMessageType('DialogStateIn', (_message.Message,), dict(
  DESCRIPTOR = _DIALOGSTATEIN,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.DialogStateIn)
  ))
_sym_db.RegisterMessage(DialogStateIn)

AudioOut = _reflection.GeneratedProtocolMessageType('AudioOut', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOOUT,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.AudioOut)
  ))
_sym_db.RegisterMessage(AudioOut)

DialogStateOut = _reflection.GeneratedProtocolMessageType('DialogStateOut', (_message.Message,), dict(
  DESCRIPTOR = _DIALOGSTATEOUT,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.DialogStateOut)
  ))
_sym_db.RegisterMessage(DialogStateOut)

AssistRequest = _reflection.GeneratedProtocolMessageType('AssistRequest', (_message.Message,), dict(
  DESCRIPTOR = _ASSISTREQUEST,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.AssistRequest)
  ))
_sym_db.RegisterMessage(AssistRequest)

AssistResponse = _reflection.GeneratedProtocolMessageType('AssistResponse', (_message.Message,), dict(
  DESCRIPTOR = _ASSISTRESPONSE,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.AssistResponse)
  ))
_sym_db.RegisterMessage(AssistResponse)

SpeechRecognitionResult = _reflection.GeneratedProtocolMessageType('SpeechRecognitionResult', (_message.Message,), dict(
  DESCRIPTOR = _SPEECHRECOGNITIONRESULT,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.SpeechRecognitionResult)
  ))
_sym_db.RegisterMessage(SpeechRecognitionResult)

DeviceConfig = _reflection.GeneratedProtocolMessageType('DeviceConfig', (_message.Message,), dict(
  DESCRIPTOR = _DEVICECONFIG,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.DeviceConfig)
  ))
_sym_db.RegisterMessage(DeviceConfig)

DeviceAction = _reflection.GeneratedProtocolMessageType('DeviceAction', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEACTION,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.DeviceAction)
  ))
_sym_db.RegisterMessage(DeviceAction)

DeviceLocation = _reflection.GeneratedProtocolMessageType('DeviceLocation', (_message.Message,), dict(
  DESCRIPTOR = _DEVICELOCATION,
  __module__ = 'google.assistant.embedded.v1alpha2.embedded_assistant_pb2'
  # @@protoc_insertion_point(class_scope:google.assistant.embedded.v1alpha2.DeviceLocation)
  ))
_sym_db.RegisterMessage(DeviceLocation)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n&com.google.assistant.embedded.v1alpha2B\016AssistantProtoP\001ZJgoogle.golang.org/genproto/googleapis/assistant/embedded/v1alpha2;embedded'))

_EMBEDDEDASSISTANT = _descriptor.ServiceDescriptor(
  name='EmbeddedAssistant',
  full_name='google.assistant.embedded.v1alpha2.EmbeddedAssistant',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=2216,
  serialized_end=2352,
  methods=[
  _descriptor.MethodDescriptor(
    name='Assist',
    full_name='google.assistant.embedded.v1alpha2.EmbeddedAssistant.Assist',
    index=0,
    containing_service=None,
    input_type=_ASSISTREQUEST,
    output_type=_ASSISTRESPONSE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_EMBEDDEDASSISTANT)

DESCRIPTOR.services_by_name['EmbeddedAssistant'] = _EMBEDDEDASSISTANT

# @@protoc_insertion_point(module_scope)
